#ifndef _PTOOLS_ARGS_H
#define _PTOOLS_ARGS_H

/*
 * pTools: Process Information Utilities
 * Stephen Oberther
 * oberther@cs.fsu.edu
 *
 * Header file for argument processing functions found
 * in libptools.
 */
 
#include <proc/readproc.h>

/* Error Values returned from ptools_arg_setup() */
#define NO_ERROR     0
#define INVAL_PID   -1   /* Invalid PID specified on command line */
#define MEM_ERR     -2   /* Unable to allocate memory via malloc() etc */
#define OPT_ERR     -3   /* Unknown option found in arguments */
#define NO_PARAM    -4   /* No parameter given in an option requiring one */
#define LIBPROC_ERR -5   /* Error during a libproc function call, 
			  * not our fault */
#define INVAL_ARG   -6   /* Invalid argument passed to ptools_arg_setup()
			  * Either argcnt or args was invalid
			  */
/*
 * int ptools_arg_setup(int, const char **, 
 *                  const char *, (int *)(char)):
 *
 * Initializes internal data structures for all future calls
 *  to ptools_arg_getnext().  Parses argument from command line
 *  by using getopt() and any valid argument is sent to fptr.
 *  All other non-arguments are taken as PID values and stored internally.
 *  These PID's are sent to the libproc setup function so that libproc
 *  can handle returning the proc related information.
 *
 *  Return -1 on error and sets ptools_errno to an appropriate
 * error value.  Returns 0 on success.
 */
int ptools_arg_setup(int argcnt, char * const args[], 
		     char * const opts, void *fptr(char));



/*
 * proc_t *ptools_arg_getnext(void):
 *  Returns a pointer to a valid proc_t entry, or
 * NULL on error.
 *
 *  NOTE: It is the callers responsibility to free()
 * the memory region used by the proc_t * by calling
 * freeproc(proc_t *)
 * 
 *      This function is non-reentrant.
 */
proc_t *ptools_arg_getnext(void);



/*
 * void ptools_arg_finish(void):
 *   Cleanup the memory used maintaining the linked-list
 * of PID's.  No return value.
 */
void ptools_arg_finish(void);

#endif
