#ifndef _PTOOLS_PID_H
#define _PTOOLS_PID_H

/*
 * pTools: Process Information Utilities
 * Stephen Oberther
 * oberther@cs.fsu.edu
 *
 * PID Processing functions available through libptools
 */
#include <sys/types.h>

/*
 * AllowExamine(pid_t):
 *    See if we should allow (pid) to be
 * examined.  This is a security function.
 *
 * NOTE:  This may not be used in any of the
 * ptools but has been left in just incase.
 *
 * Return 0 on success (allowed), -1 on error,
 * 1 if access is not allowed
 */
int AllowExamine(pid_t pid);

/*
 * ValidPid(pid_t):
 *    See if (pid) is a valid proccess
 * on the system
 *
 * Return 0 if valid, -1 otherwise
 */
int ValidPid(pid_t pid);

/*
 * OpenPID(pid_t, char *):
 *    Open the specified proc file of pid
 * Return open result, ie -1 on error, or a valid
 * file descriptor on success.  errno set on error,
 * see open(2) for more info on error codes.
 */
int OpenPid(pid_t pid, char *fname);

/*
 * fOpenPid(pid_t, char *):
 *   Same as above using the fopen(3) call
 * instead.
 */
FILE *fOpenPid(pid_t pid, char *fname);

#endif
