#ifndef _SIG_LIST_H
#define _SIG_LIST_H

/*
 * pTools: Process Information Utilities
 * Stephen Oberther
 * oberther@cs.fsu.edu
 *
 * sig_list.h
 *
 * Structure to provide signal number to signal name mapping.
 * 
 * Based off information in libc implementation by Sun Microsystems, Inc.
 */

#include <signal.h>

/* Convert sig into a string representation.  String
 * representation is stored in buf and will not be
 * longer than bufln.  The value stored is also returned
 *
 * Null is returned on error.
 */
char *signum2str(int sig, char *buf, size_t bufln);

/* Convert str into the numerical equivalent.  On error
 * -1 is returned, a valid signal number is returned on
 * success
 */
int str2signum(char *str);


/*
 * unsigned long long ConvertMask(char *):
 *   Convert the string containing the signal
 * mask into an unsigned long long.  Return
 * values or -1 on error.
 */
unsigned long long ConvertMask(char *str);


#ifdef _USE_SIGNAL_LIST_

struct sigmap {
  const char *sigstr;
  const int signum;
};

static struct sigmap signal_list[] = {
#ifdef SIGHUP
  { "HUP",       SIGHUP },
#endif
#ifdef SIGINT
  { "INT",       SIGINT },
#endif
#ifdef SIGQUIT
  { "QUIT",      SIGQUIT },
#endif
#ifdef SIGILL
  { "ILL",       SIGILL },
#endif
#ifdef SIGTRAP
  { "TRAP",      SIGTRAP },
#endif
#ifdef SIGABRT
  { "ABRT",      SIGABRT },
#endif
#ifdef SIGIOT
  { "IOT",       SIGIOT },
#endif
#ifdef SIGBUS
  { "BUS",       SIGBUS },
#endif
#ifdef SIGFPE
  { "FPE",       SIGFPE },
#endif
#ifdef SIGKILL
  { "KILL",      SIGKILL },
#endif
#ifdef SIGUSR1
  { "USR1",      SIGUSR1 },
#endif
#ifdef SIGSEGV
  { "SEGV",      SIGSEGV },
#endif
#ifdef SIGUSR2
  { "USR2",      SIGUSR2 },
#endif
#ifdef SIGPIPE
  { "PIPE",      SIGPIPE },
#endif
#ifdef SIGALRM
  { "ALRM",      SIGALRM },
#endif
#ifdef SIGTERM
  { "TERM",      SIGTERM },
#endif
#ifdef SIGSTKFLT
  { "STKFLT",    SIGSTKFLT },
#endif
#ifdef SIGCHLD
  { "CHLD",      SIGCHLD },
#endif
#ifdef SIGCONT
  { "CONT",      SIGCONT },
#endif
#ifdef SIGSTOP
  { "STOP",      SIGSTOP },
#endif
#ifdef SIGTSTP
  { "TSTP",      SIGTSTP },
#endif
#ifdef SIGTTIN
  { "TTIN",      SIGTTIN },
#endif
#ifdef SIGTTOU
  { "TTOU",      SIGTTOU },
#endif
#ifdef SIGURG
  { "URG",       SIGURG },
#endif
#ifdef SIGXCPU
  { "XCPU",      SIGXCPU },
#endif
#ifdef SIGXFSZ
  { "XFSZ",      SIGXFSZ },
#endif
#ifdef SIGVTALRM
  { "VTALRM",    SIGVTALRM },
#endif
#ifdef SIGPROF
  { "PROF",      SIGPROF },
#endif
#ifdef SIGWINCH
  { "WINCH",     SIGWINCH },
#endif
  /* Same as POLL, and SUN uses POLL
    #ifdef SIGIO
    { "IO",        SIGIO },
    #endif
  */
#ifdef SIGPOLL
  { "POLL",      SIGPOLL },
#endif
#ifdef SIGPWR
  { "PWR",       SIGPWR },
#endif
#ifdef SIGSYS
  { "SYS",       SIGSYS },
#endif
#ifdef SIGUNUSED
  { "UNUSED",    SIGUNUSED },
#endif
  /* These are found in the Solaris OS by SUN Microsystems, Inc.
   * and are not included in Linux
   *
    #ifdef SIGCANCEL
    { "CANCEL",    SIGCANCEL },
    #endif
    #ifdef SIGCLD
    { "CLD",       SIGCLD },
    #endif
    #ifdef SIGEMT
    { "EMT",       SIGEMT },
    #endif
    #ifdef SIGFREEZE
    { "FREEZE",    SIGFREEZE },
    #endif
    #ifdef SIGLOST
    { "LOST",      SIGLOST },
    #endif
    #ifdef SIGLWP
    { "LWP",       SIGLWP },
    #endif
    #ifdef SIGTHAW
    { "THAW",      SIGTHAW },
    #endif
    #ifdef SIGWAITING
    { "WAITING",   SIGWAITING },
    #endif
  */
  { NULL, 0 }
};

#endif /* _USE_SIGNAL_LIST_ */

#endif
