#ifndef _SYSCALL_LIST_H
#define _SYSCALL_LIST_H

/* WARNING: DO NOT EDIT THIS FILE BY HAND */
/* THIS FILE IS GENERATED BY ./gen_syscall_info.pl */
/* IF MAX_NUM_ARGS changes in ptools.h the script */
/* must be updated                                */


/* pTools: Process Information Utilities
 * Stephen Oberther
 * oberther@cs.fsu.edu
 *
 * Functions to handle signal number to name and name to number conversions.
 */#include "./ptools.h"

/* Convert syscall number into a string representation
 * String will be stored in buf and will not be longer
 * than bufln.  The value stored is also returned.
 *
 * NULL is returned on error.
 */
char *syscallnum2str(int syscall, char *buf, size_t bufln);


/* Convert str into the numerical equivalent.  On erro
 * -1 is returned, a valid syscall number is returned
 * on success
 */
int str2syscallnum(char *str);

/* Return the number of arguments that the system call has */
int syscall_numargs(int sc_num);

#define FIRST_SYSCALL     1


struct arg_info {
  const char *arg_type;
  const char *arg_name;
};

struct syscall_map {
  const char *syscall_str;
  const int syscall_num;
  const char *syscall_ret;
  const int syscall_numargs;
  const struct arg_info syscall_args[MAX_NUM_ARGS];
};

static struct syscall_map syscall_list[] = {
  {"sys_ni_syscall", 0, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_exit", 1, "long", 1, { {"int", "error_code"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_fork", 2, "int", 1, { {"struct pt_regs", "regs"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_read", 3, "ssize_t", 3, { {"unsigned int", "fd"}, 
                    {"char *", "buf"}, {"size_t", "count"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_write", 4, "ssize_t", 3, { {"unsigned int", "fd"}, 
                    {"const char *", "buf"}, {"size_t", "count"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_open", 5, "long", 3, { {"const char *", "filename"}, 
                    {"int", "flags"}, {"int", "mode"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_close", 6, "long", 1, { {"unsigned int", "fd"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_waitpid", 7, "long", 3, { {"pid_t", "pid"}, 
                    {"unsigned int *", "stat_addr"}, {"int", "options"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_creat", 8, "long", 2, { {"const char *", "pathname"}, 
                    {"int", "mode"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_link", 9, "long", 2, { {"const char *", "oldname"}, 
                    {"const char *", "newname"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_unlink", 10, "long", 1, { {"const char *", "pathname"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_execve", 11, "int", 1, { {"struct pt_regs", "regs"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_chdir", 12, "long", 1, { {"const char *", "filename"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_time", 13, "long", 1, { {"int *", "tloc"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_mknod", 14, "long", 3, { {"const char *", "filename"}, 
                    {"int", "mode"}, {"dev_t", "dev"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_chmod", 15, "long", 2, { {"const char *", "filename"}, 
                    {"mode_t", "mode"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_lchown16", 16, "long", 3, { {"const char *", "filename"}, 
                    {"old_uid_t", "user"}, {"old_gid_t", "group"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_ni_syscall", 17, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_stat", 18, "long", 2, { {"char *", "filename"}, 
                    {"struct __old_kernel_stat *", "statbuf"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_lseek", 19, "off_t", 3, { {"unsigned int", "fd"}, 
                    {"off_t", "offset"}, {"unsigned int", "origin"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_getpid", 20, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_mount", 21, "long", 5, { {"char *", "dev_name"}, 
                    {"char *", "dir_name"}, {"char *", "type"}, 
                    {"unsigned long", "flags"}, {"void *", "data"}, 
                    {NULL, NULL} } },
  {"sys_oldumount", 22, "long", 1, { {"char *", "name"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_setuid16", 23, "long", 1, { {"old_uid_t", "uid"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_getuid16", 24, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_stime", 25, "long", 1, { {"int *", "tptr"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_ptrace", 26, "int", 4, { {"long", "request"}, 
                    {"long", "pid"}, {"long", "addr"}, 
                    {"long", "data"}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_alarm", 27, "unsignedlong", 1, { {"unsigned int", "seconds"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_fstat", 28, "long", 2, { {"unsigned int", "fd"}, 
                    {"struct __old_kernel_stat *", "statbuf"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_pause", 29, "int", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_utime", 30, "long", 2, { {"char *", "filename"}, 
                    {"struct utimbuf *", "times"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_ni_syscall", 31, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_ni_syscall", 32, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_access", 33, "long", 2, { {"const char *", "filename"}, 
                    {"int", "mode"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_nice", 34, "long", 1, { {"int", "increment"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_ni_syscall", 35, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_sync", 36, "void", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_kill", 37, "long", 2, { {"int", "pid"}, 
                    {"int", "sig"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_rename", 38, "long", 2, { {"const char *", "oldname"}, 
                    {"const char *", "newname"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_mkdir", 39, "long", 2, { {"const char *", "pathname"}, 
                    {"int", "mode"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_rmdir", 40, "long", 1, { {"const char *", "pathname"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_dup", 41, "long", 1, { {"unsigned int", "fildes"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_pipe", 42, "int", 1, { {"unsigned long *", "fildes"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_times", 43, "long", 1, { {"struct tms *", "tbuf"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_ni_syscall", 44, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_brk", 45, "unsignedlong", 1, { {"unsigned long", "brk"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_setgid16", 46, "long", 1, { {"old_gid_t", "gid"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_getgid16", 47, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_signal", 48, "unsignedlong", 2, { {"int", "sig"}, 
                    {"__sighandler_t", "handler"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_geteuid16", 49, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_getegid16", 50, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_acct", 51, "long", 1, { {"const char *", "filename"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_umount", 52, "long", 2, { {"char *", "name"}, 
                    {"int", "flags"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_ni_syscall", 53, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_ioctl", 54, "long", 3, { {"unsigned int", "fd"}, 
                    {"unsigned int", "cmd"}, {"unsigned long", "arg"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_fcntl", 55, "long", 3, { {"unsigned int", "fd"}, 
                    {"unsigned int", "cmd"}, {"unsigned long", "arg"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_ni_syscall", 56, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_setpgid", 57, "long", 2, { {"pid_t", "pid"}, 
                    {"pid_t", "pgid"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_ni_syscall", 58, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_olduname", 59, "int", 1, { {"struct oldold_utsname *", "name"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_umask", 60, "long", 1, { {"int", "mask"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_chroot", 61, "long", 1, { {"const char *", "filename"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_ustat", 62, "long", 2, { {"dev_t", "dev"}, 
                    {"struct ustat *", "ubuf"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_dup2", 63, "long", 2, { {"unsigned int", "oldfd"}, 
                    {"unsigned int", "newfd"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_getppid", 64, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_getpgrp", 65, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_setsid", 66, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_sigaction", 67, "int", 3, { {"int", "sig"}, 
                    {"const struct old_sigaction", "*act"}, {"struct old_sigaction", "*oact"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_sgetmask", 68, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_ssetmask", 69, "long", 1, { {"int", "newmask"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_setreuid16", 70, "long", 2, { {"old_uid_t", "ruid"}, 
                    {"old_uid_t", "euid"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_setregid16", 71, "long", 2, { {"old_gid_t", "rgid"}, 
                    {"old_gid_t", "egid"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_sigsuspend", 72, "int", 3, { {"int", "history0"}, 
                    {"int", "history1"}, {"old_sigset_t", "mask"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_sigpending", 73, "long", 1, { {"old_sigset_t", "*set"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_sethostname", 74, "long", 2, { {"char", "*name"}, 
                    {"int", "len"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_setrlimit", 75, "long", 2, { {"unsigned int", "resource"}, 
                    {"struct rlimit", "*rlim"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_old_getrlimit", 76, "long", 2, { {"unsigned int", "resource"}, 
                    {"struct rlimit", "*rlim"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_getrusage", 77, "long", 2, { {"int", "who"}, 
                    {"struct rusage", "*ru"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_gettimeofday", 78, "long", 2, { {"struct timeval", "*tv"}, 
                    {"struct timezone", "*tz"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_settimeofday", 79, "long", 2, { {"struct timeval", "*tv"}, 
                    {"struct timezone", "*tz"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_getgroups16", 80, "long", 2, { {"int", "gidsetsize"}, 
                    {"old_gid_t", "*grouplist"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_setgroups16", 81, "long", 2, { {"int", "gidsetsize"}, 
                    {"old_gid_t", "*grouplist"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"old_select", 82, "int", 1, { {"struct sel_arg_struct", "*arg"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_symlink", 83, "long", 2, { {"const char *", "oldname"}, 
                    {"const char *", "newname"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_lstat", 84, "long", 2, { {"char *", "filename"}, 
                    {"struct __old_kernel_stat *", "statbuf"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_readlink", 85, "long", 3, { {"const char *", "path"}, 
                    {"char *", "buf"}, {"int", "bufsiz"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_uselib", 86, "long", 1, { {"const char *", "library"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_swapon", 87, "long", 2, { {"const char *", "specialfile"}, 
                    {"int", "swap_flags"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_reboot", 88, "long", 4, { {"int", "magic1"}, 
                    {"int", "magic2"}, {"unsigned int", "cmd"}, 
                    {"void *", "arg"}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"old_readdir", 89, "int", 3, { {"unsigned int", "fd"}, 
                    {"void *", "dirent"}, {"unsigned int", "count"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"old_mmap", 90, "int", 1, { {"struct mmap_arg_struct", "*arg"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_munmap", 91, "long", 2, { {"unsigned long", "addr"}, 
                    {"size_t", "len"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_truncate", 92, "long", 2, { {"const char *", "path"}, 
                    {"unsigned long", "length"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_ftruncate", 93, "long", 2, { {"unsigned int", "fd"}, 
                    {"unsigned long", "length"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_fchmod", 94, "long", 2, { {"unsigned int", "fd"}, 
                    {"mode_t", "mode"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_fchown16", 95, "long", 3, { {"unsigned int", "fd"}, 
                    {"old_uid_t", "user"}, {"old_gid_t", "group"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_getpriority", 96, "long", 2, { {"int", "which"}, 
                    {"int", "who"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_setpriority", 97, "long", 3, { {"int", "which"}, 
                    {"int", "who"}, {"int", "niceval"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_ni_syscall", 98, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_statfs", 99, "long", 2, { {"const char *", "path"}, 
                    {"struct statfs *", "buf"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_fstatfs", 100, "long", 2, { {"unsigned int", "fd"}, 
                    {"struct statfs *", "buf"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_ioperm", 101, "int", 3, { {"unsigned long", "from"}, 
                    {"unsigned long", "num"}, {"int", "turn_on"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_socketcall", 102, "long", 2, { {"int", "call"}, 
                    {"unsigned long", "*args"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_syslog", 103, "long", 3, { {"int", "type"}, 
                    {"char *", "buf"}, {"int", "len"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_setitimer", 104, "long", 3, { {"int", "which"}, 
                    {"struct itimerval", "*value"}, {"struct itimerval", "*ovalue"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_getitimer", 105, "long", 2, { {"int", "which"}, 
                    {"struct itimerval", "*value"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_newstat", 106, "long", 2, { {"char *", "filename"}, 
                    {"struct stat *", "statbuf"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_newlstat", 107, "long", 2, { {"char *", "filename"}, 
                    {"struct stat *", "statbuf"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_newfstat", 108, "long", 2, { {"unsigned int", "fd"}, 
                    {"struct stat *", "statbuf"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_uname", 109, "int", 1, { {"struct old_utsname *", "name"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_iopl", 110, "int", 1, { {"unsigned long", "unused"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_vhangup", 111, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_ni_syscall", 112, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_vm86old", 113, "int", 1, { {"struct vm86_struct *", "v86"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_wait4", 114, "long", 4, { {"pid_t", "pid"}, 
                    {"unsigned int *", "stat_addr"}, {"int", "options"}, 
                    {"struct rusage *", "ru"}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_swapoff", 115, "long", 1, { {"const char *", "specialfile"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_sysinfo", 116, "long", 1, { {"struct sysinfo", "*info"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_ipc", 117, "int", 6, { {"uint", "call"}, 
                    {"int", "first"}, {"int", "second"}, 
                    {"int", "third"}, {"void", "*ptr"}, 
                    {"long", "fifth"} } },
  {"sys_fsync", 118, "long", 1, { {"unsigned int", "fd"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_sigreturn", 119, "int", 1, { {"unsigned long", "__unused"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_clone", 120, "int", 1, { {"struct pt_regs", "regs"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_setdomainname", 121, "long", 2, { {"char", "*name"}, 
                    {"int", "len"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_newuname", 122, "long", 1, { {"struct new_utsname *", "name"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_modify_ldt", 123, "int", 3, { {"int", "func"}, 
                    {"void", "*ptr"}, {"unsigned long", "bytecount"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_adjtimex", 124, "long", 1, { {"struct timex", "*txc_p"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_mprotect", 125, "long", 3, { {"unsigned long", "start"}, 
                    {"size_t", "len"}, {"unsigned long", "prot"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_sigprocmask", 126, "long", 3, { {"int", "how"}, 
                    {"old_sigset_t", "*set"}, {"old_sigset_t", "*oset"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_create_module", 127, "unsignedlong", 2, { {"const char", "*name_user"}, 
                    {"size_t", "size"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_init_module", 128, "long", 2, { {"const char", "*name_user"}, 
                    {"struct module", "*mod_user"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_delete_module", 129, "long", 1, { {"const char", "*name_user"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_get_kernel_syms", 130, "long", 1, { {"struct kernel_sym", "*table"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_quotactl", 131, "long", 4, { {"int", "cmd"}, 
                    {"const char", "*special"}, {"int", "id"}, 
                    {"caddr_t", "addr"}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_getpgid", 132, "long", 1, { {"pid_t", "pid"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_fchdir", 133, "long", 1, { {"unsigned int", "fd"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_bdflush", 134, "long", 2, { {"int", "func"}, 
                    {"long", "data"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_sysfs", 135, "long", 3, { {"int", "option"}, 
                    {"unsigned long", "arg1"}, {"unsigned long", "arg2"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_personality", 136, "long", 1, { {"unsigned long", "personality"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_ni_syscall", 137, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_setfsuid16", 138, "long", 1, { {"old_uid_t", "uid"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_setfsgid16", 139, "long", 1, { {"old_gid_t", "gid"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_llseek", 140, "long", 5, { {"unsigned int", "fd"}, 
                    {"unsigned long", "offset_high"}, {"unsigned long", "offset_low"}, 
                    {"loff_t *", "result"}, {"unsigned int", "origin"}, 
                    {NULL, NULL} } },
  {"sys_getdents", 141, "long", 3, { {"unsigned int", "fd"}, 
                    {"void *", "dirent"}, {"unsigned int", "count"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_select", 142, "long", 5, { {"int", "n"}, 
                    {"fd_set", "*inp"}, {"fd_set", "*outp"}, 
                    {"fd_set", "*exp"}, {"struct timeval", "*tvp"}, 
                    {NULL, NULL} } },
  {"sys_flock", 143, "long", 2, { {"unsigned int", "fd"}, 
                    {"unsigned int", "cmd"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_msync", 144, "long", 3, { {"unsigned long", "start"}, 
                    {"size_t", "len"}, {"int", "flags"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_readv", 145, "ssize_t", 3, { {"unsigned long", "fd"}, 
                    {"const struct iovec *", "vector"}, {"unsigned long", "count"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_writev", 146, "ssize_t", 3, { {"unsigned long", "fd"}, 
                    {"const struct iovec *", "vector"}, {"unsigned long", "count"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_getsid", 147, "long", 1, { {"pid_t", "pid"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_fdatasync", 148, "long", 1, { {"unsigned int", "fd"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_sysctl", 149, NULL, -1, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_mlock", 150, "long", 2, { {"unsigned long", "start"}, 
                    {"size_t", "len"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_munlock", 151, "long", 2, { {"unsigned long", "start"}, 
                    {"size_t", "len"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_mlockall", 152, "long", 1, { {"int", "flags"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_munlockall", 153, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_sched_setparam", 154, "long", 2, { {"pid_t", "pid"}, 
                    {"struct sched_param", "*param"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_sched_getparam", 155, "long", 2, { {"pid_t", "pid"}, 
                    {"struct sched_param", "*param"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_sched_setscheduler", 156, "long", 3, { {"pid_t", "pid"}, 
                    {"int", "policy"}, {"struct sched_param", "*param"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_sched_getscheduler", 157, "long", 1, { {"pid_t", "pid"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_sched_yield", 158, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_sched_get_priority_max", 159, "long", 1, { {"int", "policy"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_sched_get_priority_min", 160, "long", 1, { {"int", "policy"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_sched_rr_get_interval", 161, "long", 2, { {"pid_t", "pid"}, 
                    {"struct timespec", "*interval"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_nanosleep", 162, "long", 2, { {"struct timespec", "*rqtp"}, 
                    {"struct timespec", "*rmtp"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_mremap", 163, "unsignedlong", 5, { {"unsigned long", "addr"}, 
                    {"unsigned long", "old_len"}, {"unsigned long", "new_len"}, 
                    {"unsigned long", "flags"}, {"unsigned long", "new_addr"}, 
                    {NULL, NULL} } },
  {"sys_setresuid16", 164, "long", 3, { {"old_uid_t", "ruid"}, 
                    {"old_uid_t", "euid"}, {"old_uid_t", "suid"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_getresuid16", 165, "long", 3, { {"old_uid_t", "*ruid"}, 
                    {"old_uid_t", "*euid"}, {"old_uid_t", "*suid"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_vm86", 166, "int", 2, { {"unsigned long", "subfunction"}, 
                    {"struct vm86plus_struct *", "v86"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_query_module", 167, "long", 5, { {"const char", "*name_user"}, 
                    {"int", "which"}, {"char", "*buf"}, 
                    {"size_t", "bufsize"}, {"size_t", "*ret"}, 
                    {NULL, NULL} } },
  {"sys_poll", 168, "long", 3, { {"struct pollfd *", "ufds"}, 
                    {"unsigned int", "nfds"}, {"long", "timeout"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_nfsservctl", 169, "int", 3, { {"int", "cmd"}, 
                    {"void", "*argp"}, {"void", "*resp"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_setresgid16", 170, "long", 3, { {"old_gid_t", "rgid"}, 
                    {"old_gid_t", "egid"}, {"old_gid_t", "sgid"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_getresgid16", 171, "long", 3, { {"old_gid_t", "*rgid"}, 
                    {"old_gid_t", "*egid"}, {"old_gid_t", "*sgid"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_prctl", 172, "long", 5, { {"int", "option"}, 
                    {"unsigned long", "arg2"}, {"unsigned long", "arg3"}, 
                    {"unsigned long", "arg4"}, {"unsigned long", "arg5"}, 
                    {NULL, NULL} } },
  {"sys_rt_sigreturn", 173, "int", 1, { {"unsigned long", "__unused"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_rt_sigaction", 174, "long", 4, { {"int", "sig"}, 
                    {"const struct sigaction", "*act"}, {"struct sigaction", "*oact"}, 
                    {"size_t", "sigsetsize"}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_rt_sigprocmask", 175, "long", 4, { {"int", "how"}, 
                    {"sigset_t", "*set"}, {"sigset_t", "*oset"}, 
                    {"size_t", "sigsetsize"}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_rt_sigpending", 176, "long", 2, { {"sigset_t", "*set"}, 
                    {"size_t", "sigsetsize"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_rt_sigtimedwait", 177, "long", 4, { {"const sigset_t", "*uthese"}, 
                    {"siginfo_t", "*uinfo"}, {"const struct timespec", "*uts"}, 
                    {"size_t", "sigsetsize"}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_rt_sigqueueinfo", 178, "long", 3, { {"int", "pid"}, 
                    {"int", "sig"}, {"siginfo_t", "*uinfo"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_rt_sigsuspend", 179, "int", 2, { {"sigset_t", "*unewset"}, 
                    {"size_t", "sigsetsize"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_pread", 180, "ssize_t", 4, { {"unsigned int", "fd"}, 
                    {"char *", "buf"}, {"size_t", "count"}, 
                    {"loff_t", "pos"}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_pwrite", 181, "ssize_t", 4, { {"unsigned int", "fd"}, 
                    {"const char *", "buf"}, {"size_t", "count"}, 
                    {"loff_t", "pos"}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_chown16", 182, "long", 3, { {"const char *", "filename"}, 
                    {"old_uid_t", "user"}, {"old_gid_t", "group"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_getcwd", 183, "long", 2, { {"char", "*buf"}, 
                    {"unsigned long", "size"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_capget", 184, "long", 2, { {"cap_user_header_t", "header"}, 
                    {"cap_user_data_t", "dataptr"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_capset", 185, "long", 2, { {"cap_user_header_t", "header"}, 
                    {"const cap_user_data_t", "data"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_sigaltstack", 186, "int", 2, { {"const stack_t", "*uss"}, 
                    {"stack_t", "*uoss"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_sendfile", 187, "ssize_t", 4, { {"int", "out_fd"}, 
                    {"int", "in_fd"}, {"off_t", "*offset"}, 
                    {"size_t", "count"}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_ni_syscall", 188, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_ni_syscall", 189, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_vfork", 190, "int", 1, { {"struct pt_regs", "regs"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_getrlimit", 191, "long", 2, { {"unsigned int", "resource"}, 
                    {"struct rlimit", "*rlim"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_mmap2", 192, "long", 6, { {"unsigned long", "addr"}, 
                    {"unsigned long", "len"}, {"unsigned long", "prot"}, 
                    {"unsigned long", "flags"}, {"unsigned long", "fd"}, 
                    {"unsigned long", "pgoff"} } },
  {"sys_truncate64", 193, "long", 2, { {"const char *", "path"}, 
                    {"loff_t", "length"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_ftruncate64", 194, "long", 2, { {"unsigned int", "fd"}, 
                    {"loff_t", "length"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_stat64", 195, "long", 3, { {"char *", "filename"}, 
                    {"struct stat64 *", "statbuf"}, {"long", "flags"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_lstat64", 196, "long", 3, { {"char *", "filename"}, 
                    {"struct stat64 *", "statbuf"}, {"long", "flags"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_fstat64", 197, "long", 3, { {"unsigned long", "fd"}, 
                    {"struct stat64 *", "statbuf"}, {"long", "flags"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_lchown", 198, "long", 3, { {"const char *", "filename"}, 
                    {"uid_t", "user"}, {"gid_t", "group"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_getuid", 199, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_getgid", 200, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_geteuid", 201, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_getegid", 202, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_setreuid", 203, "long", 2, { {"uid_t", "ruid"}, 
                    {"uid_t", "euid"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_setregid", 204, "long", 2, { {"gid_t", "rgid"}, 
                    {"gid_t", "egid"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_getgroups", 205, "long", 2, { {"int", "gidsetsize"}, 
                    {"gid_t", "*grouplist"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_setgroups", 206, "long", 2, { {"int", "gidsetsize"}, 
                    {"gid_t", "*grouplist"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_fchown", 207, "long", 3, { {"unsigned int", "fd"}, 
                    {"uid_t", "user"}, {"gid_t", "group"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_setresuid", 208, "long", 3, { {"uid_t", "ruid"}, 
                    {"uid_t", "euid"}, {"uid_t", "suid"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_getresuid", 209, "long", 3, { {"uid_t", "*ruid"}, 
                    {"uid_t", "*euid"}, {"uid_t", "*suid"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_setresgid", 210, "long", 3, { {"gid_t", "rgid"}, 
                    {"gid_t", "egid"}, {"gid_t", "sgid"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_getresgid", 211, "long", 3, { {"gid_t", "*rgid"}, 
                    {"gid_t", "*egid"}, {"gid_t", "*sgid"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_chown", 212, "long", 3, { {"const char *", "filename"}, 
                    {"uid_t", "user"}, {"gid_t", "group"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_setuid", 213, "long", 1, { {"uid_t", "uid"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_setgid", 214, "long", 1, { {"gid_t", "gid"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_setfsuid", 215, "long", 1, { {"uid_t", "uid"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_setfsgid", 216, "long", 1, { {"gid_t", "gid"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_pivot_root", 217, "long", 2, { {"const char", "*new_root"}, 
                    {"const char", "*put_old"}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_mincore", 218, "long", 3, { {"unsigned long", "start"}, 
                    {"size_t", "len"}, {"unsigned char *", "vec"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_madvise", 219, "long", 3, { {"unsigned long", "start"}, 
                    {"size_t", "len"}, {"int", "behavior"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_getdents64", 220, "long", 3, { {"unsigned int", "fd"}, 
                    {"void *", "dirent"}, {"unsigned int", "count"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_fcntl64", 221, "long", 3, { {"unsigned int", "fd"}, 
                    {"unsigned int", "cmd"}, {"unsigned long", "arg"}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_ni_syscall", 222, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {"sys_ni_syscall", 223, "long", 0, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } },
  {NULL, -1, NULL, -1, { {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL}, {NULL, NULL}, 
                    {NULL, NULL} } }
};

#endif
