/*
 * sig_list.c
 * Stephen Oberther
 * oberther@cs.fsu.edu
 *
 * Signal List helper functions
 *
 * Compile:
 *   gcc -c sig_list.c
 */

#define _USE_SIGNAL_LIST_

#include <ctype.h>
#include <string.h>
#include <stdio.h>
#include <sig_list.h>


char *signum2str(int sig, char *buf, size_t bufln) {
  int cnt, len;

  if ((bufln <= 0) || (!buf)) return NULL;
  for (cnt = 0;; cnt++) {
    if (signal_list[cnt].sigstr == NULL) break;
    if (signal_list[cnt].signum == sig) {
      len = snprintf(buf, bufln, "SIG%s", signal_list[cnt].sigstr);
/* Removed 2-20-2002 by SMO
      if (len >= bufln) buf[bufln-1] = '\0';
*/
      return buf;
    }
  }
  return NULL;
}



int str2signum(char *str) {
  int cnt;

  if (!str) return -1;

  for (cnt = 0;; cnt++) {
    if (signal_list[cnt].sigstr == NULL) break;
    if ( (strlen(signal_list[cnt].sigstr) == strlen(str)) &&
	 (strncmp(str, signal_list[cnt].sigstr, strlen(str)) == 0) ) {
      return signal_list[cnt].signum;
    }
  }
  
  return -1;
}


/*
 * unsigned long long ConvertMask(char *):
 *   Convert the string containing the signal
 * mask into an unsigned long long.  Return
 * values or -1 on error.
 */
unsigned long long ConvertMask(char *str) {
  int cnt, shift;
  char c;
  unsigned long long tmp, ret = 0;

  for(cnt = 0; cnt < strlen(str); cnt++) {
    c = tolower(str[cnt]);
    if (isdigit(c))
      tmp = c - '0';

    else if (isalpha(c)) {
      if ( (c < 'a') || (c > 'f') )
        return -1;
      tmp = c - 'a' + 10;
    }
    shift = 60 - (4 * cnt);
    
    ret |= tmp << shift;
  }

  return ret;
}


