/*
 * syscall_list.c
 *
 * Stephen Oberther
 * pTools: Process Information Utilities
 * oberther@cs.fsu.edu
 *
 * System call related function implementations.  These functions
 * map syscall number to names and names to number through
 * the syscall_list data structure.
 *
 * Compile:
 *   gcc -c syscall_list.c
 */

#include <string.h>
#include <stdio.h>
#include <syscall_list.h>

/* Convert syscall number into a string representation.
 * String will be stored in buf and will not be longer
 * than bufln.  The value stored is also returned.
 *
 * NULL is returned on error.
 */
char *syscallnum2str(int syscall, char *buf, size_t bufln) {
  int cnt;

  if ((bufln <= 0) || (!buf)) return NULL;
  for (cnt = 0;; cnt++) {
    if (syscall_list[cnt].syscall_str == NULL) break;
    if (syscall_list[cnt].syscall_num == syscall) {
      snprintf(buf, bufln, "%s", syscall_list[cnt].syscall_str);
      return buf;
    }
  }
  return NULL;
}


/* Convert str into the numerical equivalent.  On erro
 * -1 is returned, a valid syscall number is returned
 * on success
 */
int str2syscallnum(char *str) {
  int cnt;

  if (!str) return -1;

  for (cnt = 0;; cnt++) {
    if (syscall_list[cnt].syscall_str == NULL) break;
    if ( (strlen(syscall_list[cnt].syscall_str) == strlen(str)) &&
	 (strncmp(str, syscall_list[cnt].syscall_str, strlen(str)) == 0) ) {
      return syscall_list[cnt].syscall_num;
    }
  }
  return -1;
}


/* Return the number of arguments that the system call has */
int syscall_numargs(int sc_num) {

  if (sc_num < 0) return -1;

  return (syscall_list[sc_num].syscall_numargs);
}
