%{
/*
 * pTools: Process Information Utilities
 * Stephen Oberther
 * oberther@cs.fsu.edu
 *
 * Lex file to parse contents of the /proc/pid/maps file.
 */

#include <config.h>
#include <ptools_maps.h>


struct maps_ent *current, *head = NULL;


void CleanupMapsList(struct maps_ent *p);

%}

loc  [0-9a-f]{8}
perm [-rwxsp]{4}
dev  [0-9]{2}:[0-9]{2}
inode [0-9]+

 /* does not cover case where filename containes \n,
  * should be modified so that file names only valid if they
  * contain characters from the "portable filename character set"
  */
file (\/[^\/\n]+)+

%%

[ \t]+        ;

\n          { /* printf("**********************\n"); */ }

 /* Memory Location */
{loc}-{loc} { 
               current = (struct maps_ent *)malloc(sizeof(struct maps_ent));
               if (!current) {
                  fprintf(stderr, "malloc() error\n");
                  CleanupMapsList(head);
                  exit(-1);
               }
               memset(current, 0, sizeof(struct maps_ent));

               current->next = head;
               head = current;
               sscanf(yytext, "%lx-%lx", &(current->start), 
			      &(current->end));
               /*
                printf("Memory Loc: %lx-%lx\n", current->start, current->end); 
               */
            }

 /* Address Space Permissions */
{perm}      { 
               strncpy(current->perms, yytext, 5);
               /*
                 printf("Address Space perms: %s\n", current->perms); 
               */
            }

 /* Offset into the file/device etc */
{loc}       { 
               sscanf(yytext, "%lx", &(current->offset));
               /*
                 printf("Offset: %lx\n", current->offset); 
               */
            }

 /* The device maj:min numbers */
{dev}       { 
               sscanf(yytext, "%d:%d", &(current->maj),
			      &(current->min));
               /*
                 printf("Device (maj:min): %d:%d\n", current->maj,
		      current->min);
               */
            }

 /* Inode on the device */
{inode}     { 
               sscanf(yytext, "%lu", &(current->inode));
               /*
                 printf("File INode: %lu\n", current->inode);
               */
            }

 /* File name where appropriate */
{file}      { 
               strncpy(current->path, yytext, BUFLN);
               /*
                 printf("File Name: %s\n", current->path); 
               */
            }


%%

