/*
 * prun.c
 * Stephen Oberther
 * oberther@cs.fsu.edu
 * 
 * pTools: Process Information Utilities
 *
 * Restarts a process that was previously stopped by pstop
 *
 * Usage:
 *    prun <pid> . . .
 *
 * Compile:
 *    gcc -o prun prun.c -lproc -lptools
 *
 */

#include <config.h>
#include <procfs_ctl.h>


void PrintUsage(char *name) {

  fprintf(stderr, "usage:  %s pid ...\n", name);
  fprintf(stderr, "  (set stopped processes running)\n");
}


int main(int argc, char **argv) {

  int ret, ctlfd;
  proc_t *curproc;
  char buf[BUFLN];
  ctl_t msg;


  if (argc == 1) {
    PrintUsage(argv[0]);
    return -1;
  }
  else if (argc < 1) {
    PrintUsage("prun");
    return -1;
  }

  /* Initialize ptools_arg library routines */
  ret = ptools_arg_setup(argc, argv, NULL, NULL);
  if (ret < 0) {
    fprintf(stderr, "Error, ptools_arg_setup(): %d\n", ptools_errno);
    return -1;
  }

  /* Call getnext() repeatedly until no more PID's are returned */
  while(1) {
    curproc = ptools_arg_getnext();

    if (!curproc) {
      if (ptools_errno == 0) break;

      fprintf(stderr, "Error: %d with arg: %s\n", 
	      ptools_errno, ptools_arg_str);
      continue;
    }

    fprintf(stderr, "Processing PID: %d\tRunning\n", curproc->pid);

    snprintf(buf, BUFLN, "/proc/%d/ctl", curproc->pid);
    ctlfd = open(buf, O_WRONLY);

    if (ctlfd < 0) {
      switch(errno) {
      case EACCES:
	fprintf(stderr, "%d: Permission denied\n", curproc->pid);
	freeproc(curproc); continue;
	break;
	
      case ENOENT:
	fprintf(stderr, "%s: cannot control %d: no such process\n",
		argv[0], curproc->pid);
	freeproc(curproc); continue;
	break;
      };
    }

    msg = PCRUN;

    if (write(ctlfd, (char *)(&msg), sizeof(ctl_t)) < 0) {
      fprintf(stderr, "%s: error during write() to ctl file of %d\n",
	      argv[0], curproc->pid);
    }

    close(ctlfd);
    
    freeproc(curproc);
  }

  ptools_arg_finish();


  return 0;

}
