/*
 * pwait.c
 * Stephen Oberther
 *
 * pTools: Process Information Utilities
 *
 *
 */

#include <config.h>
#include <sys/poll.h>

int verbose = FALSE;

void arg_handler(char c) {

  if (c == 'v') verbose = TRUE;

}

void PrintUsage(const char *name) {
  fprintf(stderr, "usage:  %s [-v] pid ...\n", name);
  fprintf(stderr, "  (wait for processes to terminate)\n");
  fprintf(stderr, "  -v: verbose; report terminations to standard out\n");
}


int main(int argc, char **argv) {
  int ret, cnt, maxfds;
  char buf[BUFLN];
  proc_t *procinfo;
  int fd;

  struct pollfd *pptr;

  if (argc < 2) {
    PrintUsage(argv[0]);
    return -1;
  }

  /* setup the argument processing library */
  ret = ptools_arg_setup(argc, argv, "v", (void *)(arg_handler));
  if (ret < 0) {
    fprintf(stderr, "ptools_arg_setup() Error: %d\n", ptools_errno);
    return -1;
  }

  /* This is enough space for our poll() descriptor array */
  maxfds = argc-1;
  pptr = (struct pollfd *)malloc(maxfds * sizeof(struct pollfd));
  if (!pptr) {
    ptools_arg_finish();
    return -1;
  }
  memset(pptr, 0, maxfds * sizeof(struct pollfd));

  cnt = 0;
  while(1) {
    if (cnt == maxfds) break;

    procinfo = ptools_arg_getnext();

    if (!procinfo) {
      if (ptools_errno == 0) break;
      else {
	fprintf(stderr, "Error: %d with arg %s\n", ptools_errno,
		ptools_arg_str);
	continue;
      }
    }

    fprintf(stderr, "Working with %d\n", procinfo->pid);

    snprintf(buf, BUFLN, "/proc/%d/stat", procinfo->pid);
    fd = open(buf, O_RDONLY);
    if (fd < 0) { /* Process already ended ??? */
      freeproc(procinfo);
      continue;
    }

    
    pptr[cnt].fd = fd;
    pptr[cnt].events = POLLIN|POLLPRI;
    pptr[cnt].revents = 0;

    freeproc(procinfo);
    cnt++;
  } /* while(1) */

  fprintf(stderr, "Calling poll()\n");
  ret = poll(pptr, cnt, 10000);
  
  printf("poll returned %d\n", ret);

  for (ret = 0; ret < cnt; ret++)
    if (pptr[ret].revents) printf("FD(%d) revents %x\n", pptr[ret].fd,
				  pptr[ret].revents);


  ptools_arg_finish();
  free(pptr);

  return 0;
}
