/*
 * pwdx.c
 * Stephen Oberther
 * oberther@cs.fsu.edu
 *
 * pTools: Process Information Utilities
 *
 * Reports the current working directory of a process
 *
 * Compile:
 *   gcc -g -Wall -o pwdx pwdx.c
 * 
 */

#include <config.h>


void PrintUsage(char *prog) {

  fprintf(stderr, "usage:  %s pid ...\n  (show process working directory)\n", 
	  prog);
  exit(-1);

}

int main(int argc, char **argv) {

  int cnt, ret, pid;
  char buf[BUFLN], proc[BUFLN];

  if (argc == 1) PrintUsage(argv[0]);

  for (cnt = 1; cnt < argc; cnt++) {
    pid = atoi(argv[cnt]);

    if ( ValidPid((pid_t)pid) == 0 ) {
      snprintf(proc, BUFLN, "/proc/%d/cwd", pid);

      ret = readlink(proc, buf, BUFLN);

      if (ret < 0) {
	/* Determine Error message to print */
	switch(errno) {
	case EACCES:
	  printf("pwdx: cannot resolve cwd for %d: Permission denied\n", pid);
	  break;
	default:
	  perror("readlink()");
	};
      }
      else {
	buf[ret] = '\0';
	printf("%d:  %s\n", pid, buf);
      }

    } /* ValidPid */
    else
      printf("pwdx: cannot examine %d: no such process\n", pid);

  }
  
  return 0;

}
